@@ -245,6 +245,7 @@ class resonance_lines(object):
               self.Qy_max = np.floor(Qy_range)+1.05
   
         self.periodicity = periodicity
+        self.orders = orders
                                       
         nx, ny = [], []
   
@@ -572,19 +573,15 @@ class footprint:
     https://github.com/xsuite/xtrack/blob/main/examples/spacecharge/001_spacecharge_footprint.py
     """    
 
+    # Return grid of x and y coordinates from range of polar coordinates
     def initial_xy_polar(r_min, r_max, r_N, theta_min, theta_max, theta_N):
-        """ 
-        Return grid of x and y coordinates from range of polar coordinates
-        """
         return np.array([[(r*np.cos(theta),r*np.sin(theta)) for r in np.linspace(r_min,r_max,r_N)] for theta in np.linspace(theta_min,theta_max,theta_N)])
 
+    # Return x-y grid of x and y coordinates from range of cartesian coordinates 
     def initial_xy_cartesian(x_min, x_max, x_N, y_min, y_max, y_N):
-        """
-        Return x-y grid of x and y coordinates from range of cartesian coordinates 
-        """
         return np.array([[(x,y) for x in np.linspace(x_min,x_max,x_N)] for y in np.linspace(y_min,y_max,y_N)])
 
-
+    # Draw footprint from stacked xy coordinates
     def draw_footprint(A, axis_object=None, figure_object=None, axis=0, linewidth=4):
         """
         Input A should be a 3-D numpy array with shape (Nx,Ny,2)
